@@ -7,6 +7,8 @@ module Plugin::PhotoSupport
   INSTAGRAM_PATTERN = %r{\Ahttps?://(?:instagr\.am|(?:www\.)?instagram\.com)/p/([a-zA-Z0-9_\-]+)/}
 
   class << self
+    extend Memoist
+
     # Twitter cardsのURLを画像のURLに置き換える。
     # HTMLを頻繁にリクエストしないように、このメソッドを通すことでメモ化している。
     # ==== Args
@@ -202,7 +204,7 @@ Plugin.create :photo_support do
     img = Plugin::PhotoSupport.d250g2(display_url)
     open(img) if img
   end
-  
+
   # vine
   defimageopener('vine', %r<\Ahttps?://vine\.co/v/[a-zA-Z0-9]+>) do |display_url|
     connection = HTTPClient.new
@@ -212,4 +214,14 @@ Plugin.create :photo_support do
     result = doc.css('meta[property="twitter:image:src"]')
     open(result.attribute('content').value)
   end
+
+  defimageopener('彩の庭', %r{\Ahttp://haruicon\.com/ayanoniwa?\Z}) do |display_url|
+    connection = HTTPClient.new
+    page = connection.get_content(display_url)
+    next nil if page.empty?
+    doc = Nokogiri::HTML(page)
+    path = doc.css('img').attribute('src').value
+    img = URI.join("http://haruicon.com", path)
+    open(img)
+  end
 end
